UpdateDialogService class

A centralized service class for displaying update dialogs.

This class provides a single, consistent entry point to show any of the update dialogs, abstracting away the underlying implementation details and promoting code reuse.

Constructors

UpdateDialogService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

show({required BuildContext context, required UpdateDialog dialogType, String version = "1.0.1", List<String> updates = const ["Bug fixes", "New features", "Performance improvements"], String title = "New Update is Available", String subtitle = "It seems you're using an older app version.\nUpdate for the newest features and experience.", String closeText = "CLOSE", String updateText = "GET IT NOW!", VoidCallback? onUpdate, VoidCallback? onCancel, VoidCallback? onClose, bool isDark = false, bool barrierDismissible = true}) Future<void>
Displays a specific update dialog based on the provided dialogType.