dialog_kit library
Classes
- AccountSetupDialog001Config
- ======================== 001: OTP / Account Verification Dialog Config
- AccountSetupDialog002Config
- ======================== 002: Email OTP Verification Dialog Config
- AccountSetupDialog003Config
- ======================== 003: Phone OTP Multi-Stage Dialog Config
- AccountSetupDialog004Config
- ======================== 004: Simple Phone Input Dialog Config
- AccountSetupDialog005Config
- ======================== 005: Success Dialog Config
- AccountSetupDialogConfig
- Base class for all alert dialog configurations
- AccountSetupDialogService
- Centralized service to show account setup dialogs
- AlertDialog001Config
-
Configuration for
AlertDialog001(Confirmation / Yes-No dialog) - AlertDialog002Config
-
Configuration for
AlertDialog002(Newsletter subscription dialog) - AlertDialogConfig
- Base class for alert dialog configs
- AlertDialogService
- Centralized service to show alert dialogs
- NoInternetDialog001Config
-
Configuration class for
NoInternetDialog001. Use this to provide all necessary parameters via the service. - NoInternetDialog002Config
-
Configuration class for
NoInternetDialog002. Use this to provide all necessary parameters via the service. - NoInternetDialog003Config
-
Configuration class for
NoInternetDialog003. Use this to provide all necessary parameters via the service. - NoInternetDialogConfig
- Base abstract class for No Internet dialog configs.
- NoInternetDialogService
- A centralized service class for displaying no-internet dialogs.
- RatingDialog001Config
-
Configuration class for
RatingDialog001. Use this to provide all necessary parameters to the dialog via a service. - RatingDialog002Config
-
Configuration class for
RatingDialog002. Use this to pass all customization options to the dialog via a service. - RatingDialog003Config
-
Configuration class for
RatingDialog003. Use this to pass all customization options to the dialog via a service. - RatingDialog004Config
-
Configuration class for
RatingDialog004. Use this to pass all customization options to the dialog via a service. - RatingDialog005Config
-
Configuration class for
RatingDialog005. Use this to pass all customization options to the dialog via a service. - RatingDialog006Config
-
Configuration class for
RatingDialog006. Use this to pass all customization options to the dialog via a service. - RatingDialogConfig
- RatingDialogService
- A centralized service class for displaying rating dialogs.
- ResultDialogService
- A centralized service class for displaying result dialogs.
- UpdateDialogService
- A centralized service class for displaying update dialogs.
Enums
- AccountSetupDialogType
- Enum to identify the type of account setup dialog
- AlertDialogType
- Enum to identify the type of alert dialog to display
- NoInternetDialogType
- Enum to identify the specific no-internet dialog style to be displayed.
- RatingDialogType
- Enum to identify the specific rating dialog style to be displayed.
- ResultDialog
- An enum to identify the specific result dialog style to be displayed.
- UpdateDialog
- An enum to identify the specific update dialog style to be displayed. Each value corresponds to a uniquely designed dialog in the package.